Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
repo_ctx / __init__.py |  | 1 | 0 | 0 |  | 100%
repo_ctx / __main__.py |  | 195 | 195 | 0 |  | 0%
repo_ctx / config.py |  | 121 | 22 | 0 |  | 82%
repo_ctx / core.py |  | 137 | 137 | 0 |  | 0%
repo_ctx / gitlab_client.py |  | 36 | 36 | 0 |  | 0%
repo_ctx / mcp_server.py |  | 106 | 106 | 0 |  | 0%
repo_ctx / models.py |  | 41 | 0 | 0 |  | 100%
repo_ctx / parser.py |  | 43 | 0 | 0 |  | 100%
repo_ctx / providers / __init__.py |  | 11 | 0 | 0 |  | 100%
repo_ctx / providers / base.py |  | 38 | 7 | 0 |  | 82%
repo_ctx / providers / detector.py |  | 43 | 3 | 0 |  | 93%
repo_ctx / providers / exceptions.py |  | 12 | 0 | 0 |  | 100%
repo_ctx / providers / factory.py |  | 46 | 14 | 0 |  | 70%
repo_ctx / providers / github.py |  | 134 | 119 | 0 |  | 11%
repo_ctx / providers / gitlab.py |  | 111 | 96 | 0 |  | 14%
repo_ctx / providers / local.py |  | 133 | 23 | 0 |  | 83%
repo_ctx / storage.py |  | 126 | 8 | 0 |  | 94%
Total |  | 1334 | 766 | 0 |  | 43%

No items found using the specified filter.